<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/default_dune_plugin.php';
require_once 'lib/default_archive.php';
require_once 'lib/action_factory.php';
require_once 'lib/control_factory.php';
require_once 'lib/dune_exception.php';
require_once 'lib/utils.php';
require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/vod/vod_list_screen.php';
require_once 'lib/vod/vod_search_screen.php';
require_once 'lib/vod/vod_genres_screen.php';
require_once 'lib/vod/vod_movie_screen.php';
require_once 'lib/vod/vod_series_list_screen.php';
require_once 'lib/vod/vod_favorites_screen.php';
require_once 'lib/list_util.php';
#require_once 'lib/tv/tv_group_list_screen.php';
#require_once 'lib/tv/tv_favorites_screen.php';
require_once 'moidom_favorites_screen.php';//NEW
require_once 'moidom_tv_group_list_screen.php';
require_once 'moidom_tv_channel_list_screen.php';
require_once 'moidom_vod_series_list_screen.php';
require_once 'moidom_exception.php';
require_once 'moidom_config.php';
require_once 'moidom_tv.php';
require_once 'moidom_vod.php';
require_once 'moidom_session.php';
require_once 'moidom_setup_screen.php';
require_once 'moidom_vod_root_screen.php';
require_once 'moidom_vod_list_screen.php';
require_once 'moidom_entry_handler.php';

///////////////////////////////////////////////////////////////////////////

class MoidomPlugin extends DefaultDunePlugin
{
    private $session;
    private $entry_handler;

    public function __construct()
    {
        $this->session = new MoidomSession($this);
        $this->entry_handler = new MoidomEntryHandler($this->session);
        $this->tv = new MoidomTv($this->session);
        $this->vod = new MoidomVod($this->session);

        $tv_folder_views = $this->get_tv_folder_views();

        $this->add_screen(new MoidomSetupScreen($this->session, $this->tv));

        $this->add_screen(new MoidomTvGroupListScreen($this->tv, 
			MoidomConfig::GET_TV_GROUP_LIST_FOLDER_VIEWS(), $this->session));

		$this->add_screen(new MoidomTvChannelListScreen($this->tv,
            MoidomConfig::GET_TV_CHANNEL_LIST_FOLDER_VIEWS()));
        
        $this->add_screen(new MoidomTvFavoritesScreen($this->tv,
            MoidomConfig::GET_TV_CHANNEL_LIST_FOLDER_VIEWS()));

        $this->add_screen(
            new MoidomVodRootScreen($this->session, $tv_folder_views));

        $this->add_screen(
            new MoidomVodListScreen($this->session, $this->vod));

        $this->add_screen(new VodMovieScreen($this->vod));

        $this->add_screen(new MoidomVodSeriesListScreen($this->vod));

        $this->add_screen(new VodFavoritesScreen($this->vod));

        $this->add_screen(new VodSearchScreen($this->vod));

        $this->add_screen(new VodGenresScreen($this->vod));
    }

    public function unset_login()
    {
        $this->session->unset_login();
        $this->tv->unload_channels();
        $this->vod->clear_movie_cache();
        $this->vod->clear_genre_cache();

        DefaultArchive::clear_cache();
    }

    private function get_tv_folder_views()
    {
        return array(
            array
            (
                PluginRegularFolderView::async_icon_loading => false,

                PluginRegularFolderView::view_params => array
                (
                    ViewParams::num_cols => 5,
                    ViewParams::num_rows => 3,
					ViewParams::background_path=> 'plugin_file://icons/bg1.jpg',
					ViewParams::background_order => 0,
                    ViewParams::paint_details => false,
                    ViewParams::paint_sandwich => true,
                    ViewParams::sandwich_base => 'gui_skin://special_icons/sandwich_base.aai',
                    ViewParams::sandwich_mask => 'cut_icon://{name=sandwich_mask}',
                    ViewParams::sandwich_cover => 'cut_icon://{name=sandwich_cover}',
                    ViewParams::sandwich_width => 200,
                    ViewParams::sandwich_height => 140,
                    ViewParams::sandwich_icon_upscale_enabled => true,
                    ViewParams::sandwich_icon_keep_aspect_ratio => true,
                ),

                PluginRegularFolderView::base_view_item_params => array
                (
                    ViewItemParams::item_paint_icon => true,
                    ViewItemParams::item_layout => HALIGN_CENTER,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::item_paint_caption => false,
                    ViewItemParams::icon_scale_factor => 1.25,
                    ViewItemParams::icon_sel_scale_factor => 1.5,
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array (),
            ),
			array
            (
                PluginRegularFolderView::async_icon_loading => true,

                PluginRegularFolderView::view_params => array
                (
                    ViewParams::num_cols => 5,
                    ViewParams::num_rows => 4,
                    ViewParams::icon_selection_box_width => 294,
                    ViewParams::icon_selection_box_height => 162,
                    ViewParams::icon_selection_box_dy => -78,
                ),

                PluginRegularFolderView::base_view_item_params => array
                (
                    ViewItemParams::item_padding_top => 0,
                    ViewItemParams::item_padding_bottom => 0,
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::item_paint_caption => false,
                    ViewItemParams::icon_scale_factor => 1.0,
                    ViewItemParams::icon_sel_scale_factor => 1.25,
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array
                (
                    ViewItemParams::icon_path => 'plugin_file://icons/template.png',
                    ViewItemParams::item_paint_caption_within_icon => true,
                    ViewItemParams::item_caption_within_icon_color => 'black',
                ),
            ),

            array
            (
                PluginRegularFolderView::async_icon_loading => true,

                PluginRegularFolderView::view_params => array
                (
                    ViewParams::num_cols => 4,
                    ViewParams::num_rows => 3,
					ViewParams::icon_selection_box_width => 355,
                    ViewParams::icon_selection_box_height => 200,
                    ViewParams::icon_selection_box_dy => -95,
                ),

                PluginRegularFolderView::base_view_item_params => array
                (
                    ViewItemParams::icon_valign => VALIGN_CENTER,
                    ViewItemParams::item_paint_caption => false,
                    ViewItemParams::icon_scale_factor => 1.25,
                    ViewItemParams::icon_sel_scale_factor => 1.5,
                ),

                PluginRegularFolderView::not_loaded_view_item_params => array
                (
                    ViewItemParams::icon_path => 'plugin_file://icons/template.png',
                    ViewItemParams::item_paint_caption_within_icon => true,
                    ViewItemParams::item_caption_within_icon_color => 'black',
                ),
            ),
        );
    }
}

///////////////////////////////////////////////////////////////////////////
?>
