<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/hashed_array.php';
require_once 'lib/tv/abstract_tv.php';
require_once 'lib/tv/default_epg_item.php';
require_once 'lib/tv/epg_iterator.php';
require_once 'lib/user_input_handler_registry.php';

require_once 'moidom_channel.php';

///////////////////////////////////////////////////////////////////////////

class MoidomTv extends AbstractTv implements UserInputHandler
{
    private $session;
	public function get_handler_id() { return "tv"; }
    ///////////////////////////////////////////////////////////////////////

    public function __construct($session)
    {
        $this->session = $session;
		UserInputHandlerRegistry::get_instance()->register_handler($this);
        parent::__construct(
            AbstractTv::MODE_CHANNELS_1_TO_N,
            true,
            false);
    }

    public function get_fav_icon_url()
    {
        return $this->session->get_icon('favorites.png');
    }

    ///////////////////////////////////////////////////////////////////////
	public function newload(&$plugin_cookies){
	hd_print('unload');
	if(is_null($this->channels) && is_null($this->groups)){
		$this->load_channels($plugin_cookies);
	}
    }
    ///////////////////////////////////////////////////////////////////////

	///////////////////////////////////////////////////////////////////////
    public function load_channels(&$plugin_cookies)
    {
        $this->session->check_logged_in();
		$buf_time = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
		$hide_items = isset($plugin_cookies->hide_items) ? $plugin_cookies->hide_items : '';
		$hided_channels = isset($plugin_cookies->hided_channels) ? $plugin_cookies->hided_channels : 'no';
		$hided_categories = isset($plugin_cookies->hided_categories) ? $plugin_cookies->hided_categories : 'no';
		$hide_category_items = isset($plugin_cookies->hide_category_items) ? $plugin_cookies->hide_category_items : '';
        $settings = $this->session->get_settings();
        $buffering_ms = $settings->http_caching->value;
        $default_timeshift_hours = $settings->timeshift->value;
		//hd_print("buffering_ms --->>> $buffering_ms");
        $this->channels = new HashedArray();
        $this->groups = new HashedArray();
	
		$lang = $this->session->get_lang();
		
        $this->groups->put(
            new FavoritesGroup(
                $this,
                '__favorites',
                $this->session->get_language()->$lang->favorites,//'Favorites',
                "plugin_file://icons/groups/favorites.png"//$this->session->get_icon('favorites.png')
				));

        $this->groups->put(
            new AllChannelsGroup(
                $this,
                $this->session->get_language()->$lang->all_channel,//'All Channel',
                "plugin_file://icons/groups/all_channel.png"//$this->session->get_icon('all.png')
));

        $num_groups = 0;
        $num_channels = 0;
        $num_protected = 0;
        $num_have_archive = 0;
		$all_data = $this->session->get_channel_list();
		$lang = $this->session->get_lang();
		
        foreach ($all_data->groups as $g)
        {
			hd_print(json_encode($g));
			//hd_print($g->name);
			####################
			if($hided_categories == 'no')
				{
				$tv_category_id = intval($g->id);
				$qal = explode('|', $hide_category_items);
				
				if (in_array($tv_category_id, $qal)) {
					#echo "Нашел in array!!!";
					continue;
				}
				}
			####################
			
			 $this->groups->put(
                new DefaultGroup(
                    intval($g->id),
                    strval($g->name),
                    "plugin_file://icons/groups/".intval($g->id).".png"));
			
			#hd_print($g->id . '----------->' . $g->name);
            $num_groups++;
		}
            
			foreach ($all_data->channels as $c)
            {
                $have_archive = isset($c->have_archive) ?
                    ($c->have_archive == 1) : false;
                $is_protected = isset($c->protected) ?
                    ($c->protected == 1) : false;
                
                // TODO: timeshift
                $timeshift_hours = 0;
				//hd_print($this->session->get_channel_icon($c->id));
				//hd_print(json_encode($c)); //http://iptv.moi-dom.tv/img/icons/52x39/1/171.png
                $moidom_channel = new MoidomChannel(
                    $c->id,
                    $c->name,
					//$this->session->get_channel_icon($c->id),
                    "http://iptv.moi-dom.tv/img/icons/245x140/".strval($c->icon_path).".png",
                    $have_archive, $is_protected,
					$buf_time, $timeshift_hours);
					########hide########
					if($hided_channels == 'no')
					{
					$ch = strval($c->id);
					$t = ListUtil::is_in_list($hide_items, $ch);
                    if ($ch == $t)
                   
						 continue;
					}
					
					####################
                $this->channels->put($moidom_channel);
					
					foreach ($this->groups as $g){
				
					$tv_category_id = strval($g->get_id());
				
					$group = $this->groups->get($tv_category_id);

					if($tv_category_id == $c->group_id){
					$moidom_channel->add_group($group);
					$group->add_channel($moidom_channel);	}
					}
               
                

                $num_channels++;
                if ($is_protected)
                    $num_protected++;
                if ($have_archive)
                    $num_have_archive++;
            }
        

        hd_print("MOIDOM: $num_groups groups and ".
            "$num_channels channels ($num_have_archive have archive, ".
            "$num_protected protected)");
    }
	//////////////////////////////NEW////////////////////////////////////
	private function get_moidom_dialog_action($n)
    {
        $params = array('n' => $n);
        return UserInputHandlerRegistry::create_action($this,
            'dialog', $params);
    }
	///////////////
	private function get_moidom_setup_dialog_action($n)
    {
        $params = array('n' => $n);
        return UserInputHandlerRegistry::create_action($this,
            'setup_dialog', $params);
    }
	//////////////
	private function get_moidom_reset_controls_action($n)
    {
        $params = array('n' => $n);
        return UserInputHandlerRegistry::create_action($this,
            'reset_controls', $params);
    }
	private function get_set_default_behaviour_action()
    {
        return ActionFactory::change_behaviour(
            array(
                GUI_EVENT_KEY_DUNE => $this->get_moidom_dialog_action(0),
				GUI_EVENT_KEY_SETUP => $this->get_moidom_setup_dialog_action(0),///NEW JUNI
            ));
    }
	private function get_sample_dialog_defs($n)
    {
        $defs = array();
		ControlFactory::add_label($defs, null,
            '@Andy555.');
			ControlFactory::add_label($defs, null,
            'moidom');
        ControlFactory::add_label($defs, null,
            'Wait '.(10 - $n).' seconds or press RETURN to close...');
        return $defs;
    }

    private function get_sample_dialog_action($n)
    {
        return ActionFactory::show_dialog("Plugin for Dune - Moi-Dom",
            $this->get_sample_dialog_defs($n),
            false, 0,
            array(
                'actions' => array(
                    GUI_EVENT_TIMER =>
                        $this->get_moidom_reset_controls_action($n + 1),
                    GUI_EVENT_KEY_RETURN => ActionFactory::close_dialog_and_run(
                        $this->get_set_default_behaviour_action()),
                ),
                'timer' => ActionFactory::timer(900),
                'dialog_params' => array('frame_style' => DIALOG_FRAME_STYLE_GLASS)));
    }
	protected function add_close_dialog_and_apply_button(&$defs,
        $name, $caption, $width)
    {
        $params = array('button_caption_centered' => 1);
        ControlFactory::add_close_dialog_and_apply_button($defs,
            $this, null,
            $name, $caption, $width, $params);
    }

    protected function add_close_dialog_button(&$defs,
        $caption, $width)
    {
        $params = array('button_caption_centered' => 1);
        ControlFactory::add_close_dialog_button($defs,
            $caption, $width, $params);
    }
	private function get_setup_dialog_defs(&$plugin_cookies)
    {
        $defs = array();
		
		$settings = $this->session->get_settings();
		if (empty($settings))
            {
                $this->session->api_get_settings();
                $settings = $this->session->get_settings();
            }
		$bitrate = $settings->bitrate->value;
            foreach ($settings->bitrate->names as $b)
            {
                if ($b->val === $bitrate)
                {
                    $bitrate_caption = $b->title;
                    break;
                }
            }
		$buf_time = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
		$show_buf_time_ops = array();
        $show_buf_time_ops[0] = 'Default';
        $show_buf_time_ops[500] = '0.5 s';
        $show_buf_time_ops[1000] = '1 s';
        $show_buf_time_ops[2000] = '2 s';
        $show_buf_time_ops[3000] = '3 s';
        $show_buf_time_ops[5000] = '5 s';
        $show_buf_time_ops[10000] = '10 s';
        $show_buf_time_ops[15000] = '15 s';
        $show_buf_time_ops[20000] = '20 s';

        ControlFactory::add_combobox
        (
            $defs, $this, null,
            'buf_time',
            'Buffering time:',
            $buf_time, $show_buf_time_ops, 600
        );
		
		$stream_server_ops = array();
		$stream_server = $settings->stream_server->value;
        #$stream_server = intval($settings->media_server_id);
        #foreach ($settings->media_servers->item as $pair)
        #    $stream_server_ops[intval($pair->id)] = strval($pair->title);
		foreach ($settings->stream_server->list as $pair)
                $stream_server_ops[strval($pair->ip)] = strval($pair->descr);
        ControlFactory::add_combobox($defs, $this, null,
            'media_server_id', 'Broadcast Server:',
            $stream_server, $stream_server_ops, 600);

		$bitrate_ops = array();
			#foreach ($settings->bitrate->list as $v)
			foreach ($settings->bitrate->names as $b)
                #$bitrate_ops[$v] = $v;
				$bitrate_ops[$b->val] = $b->title;
        ControlFactory::add_combobox($defs, $this, null,
            'bitrate', 'Bitrate',
            $bitrate, $bitrate_ops, 600);
		//////////////////////////////////////////////
		$deit_ops = array();
		////////////////
		$deit_ops['off'] = 'Disconnected';
        $deit_ops['bob'] = 'bob';
        $deit_ops['adaptive'] = 'Adaptive';
		
		$deit = isset($plugin_cookies->deit) ? $plugin_cookies->deit : 'adaptive';
        ControlFactory::add_combobox($defs, $this, null,
            'deintrleis', 'deintrleis:',
            $deit, $deit_ops, 600);
		//////////////////////////////////////////////
		$this->add_close_dialog_and_apply_button($defs,
            'setup_apply', 'To apply', 300);
        $this->add_close_dialog_button($defs,
            'Cancel', 300);
        return $defs;
    }
	////////////////////////
	public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('TV entry handler: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");
		$control_id = $user_input->control_id;
		

        if (isset($user_input->{$control_id}))
        {
            $new_value = $user_input->{$control_id};
            hd_print("Setup: changing $control_id value to $new_value");
        }
        else
            $new_value = null;
        
        
        if ($user_input->control_id == 'dialog')
        {
            return $this->get_sample_dialog_action($user_input->n);
        }
		if ($user_input->control_id == 'setup_dialog')
        {
			return ActionFactory::show_dialog("Quick settings",
            $this->get_setup_dialog_defs($plugin_cookies),
            true, 0,
            array('dialog_params' => array('frame_style' => DIALOG_FRAME_STYLE_GLASS)));
        }
		if ($user_input->action_type === 'apply')
        {
		$channel_id = $user_input->plugin_tv_channel_id;
		$str_server = $user_input->media_server_id;
		$b_r = $user_input->bitrate;
		#hd_print("  media_server_id =============>". $str_server);
		#hd_print("  bitrate =============>". $b_r);
		$b_time = $user_input->buf_time;
        $d_inter = $user_input->deintrleis;
        $plugin_cookies->buf_time = $b_time;
		$plugin_cookies->deit = $d_inter;
        try
        {
            $this->session->api_set_setting("stream_server", $str_server);
        }
        catch (DuneException $e)
        {
            return $e->get_error_action();
        }
		try
        {
            $this->session->api_set_setting("bitrate", $b_r);
        }
        catch (DuneException $e)
        {
            return $e->get_error_action();
        }
		$this->unload_channels();
		$this->newload($plugin_cookies);
		#hd_print("channel_id-------------------------------------$channel_id");
		hd_print("OK-------------------------------------");
		return ActionFactory::reset_controls(
			$this->get_setup_dialog_defs($plugin_cookies));
		
		}
        if ($user_input->control_id == 'reset_controls')
        {
            $close_action = ActionFactory::close_dialog_and_run(
                $this->get_set_default_behaviour_action());

            if ($user_input->n >= 9)
                $timer_action = $close_action;
            else
            {
                $timer_action = 
                    $this->get_moidom_reset_controls_action($user_input->n + 1);
            }

            return ActionFactory::reset_controls(
                $this->get_sample_dialog_defs($user_input->n),
                ActionFactory::change_behaviour(
                    array(
                        GUI_EVENT_TIMER => $timer_action,
                        GUI_EVENT_KEY_RETURN => $close_action,
                    ),
                    ActionFactory::timer(900)
                )
            );
        }

        return null;
    }
	/////////////////////////////////////////////////////////////////на будущее
    public function get_tv_info(MediaURL $media_url, &$plugin_cookies)
    {
        $this->session->ensure_logged_in($plugin_cookies);
        $info = parent::get_tv_info($media_url, &$plugin_cookies);

        $info[PluginTvInfo::actions] = array(

            GUI_EVENT_KEY_DUNE => $this->get_moidom_dialog_action(0),
			GUI_EVENT_KEY_SETUP => $this->get_moidom_setup_dialog_action(0),
        );
        return $info;
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_tv_stream_url($playback_url, &$plugin_cookies)
    {
        return $this->session->api_get_stream_url($playback_url);
    }

    public function get_tv_playback_url($channel_id, $archive_ts, $protect_code, &$plugin_cookies)
    {
		$buf_time = isset($plugin_cookies->buf_time) ? $plugin_cookies->buf_time : 0;
		$deit = isset($plugin_cookies->deit) ? $plugin_cookies->deit : 'adaptive';
        $this->ensure_channels_loaded($plugin_cookies);

        $url = sprintf(MOIDOM_GET_URL_URL,
            MOIDOM::$SERVER,
            $this->session->get_sid_name(),
            $this->session->get_sid(),
            $channel_id);
        if (intval($archive_ts) > 0)
            $url .= "&gmt=$archive_ts";
        if (isset($protect_code) && $protect_code !== '')
            $url .= "&protect_code=$protect_code";
		$url .= "|||dune_params|||buffering_ms:$buf_time,deint_mode:$deit";
		hd_print("url: --->>>$url");
        return $url;
    }

    ///////////////////////////////////////////////////////////////////////
	public function get_tv_for_rec($channel_id, &$plugin_cookies)
    {
		$url = $this->get_tv_playback_url($channel_id, null, null, &$plugin_cookies);
		$tt = str_replace('http://ts://', 'http://' , $url);
		$tmp_1 = file_get_contents($tt);
		$tmp = urldecode(stripslashes($tmp_1));
		hd_print ("tmp: --->>>$tmp");
		return $tmp;
	}
    ///////////////////////////////////////////////////////////////////////

    public function get_day_epg_iterator($channel_id, $day_start_ts, &$plugin_cookies)
    {
        $this->ensure_channels_loaded($plugin_cookies);

        $day_str = gmstrftime('%d%m%y', $day_start_ts);
        $url = sprintf(MOIDOM_EPG_URL,
            MOIDOM::$SERVER,
            $this->session->get_sid_name(),
            $this->session->get_sid(),
            $channel_id,
            $day_str);

        try
        {
            $moidom_epg = $this->session->api_call($url);
        }
        catch (Exception $e)
        {
            throw $this->session->dune_api_exception($e,
                'EPG request failed.',
                true);
        }

        $epg_items = array();

        foreach ($moidom_epg->epg as $epg)
        {
            //$progname = $epg->progname;

            //$arr = explode("\n", $epg->progname, 2);
            $name = $epg->title;//count($arr) >= 1 ? trim($arr[0]) : '';
            $description = $epg->desc;//count($arr) == 2 ? $arr[1] : '';

            $start = intval($epg->ut_start);
            $end = -1;

            $epg_items[] = new DefaultEpgItem(
                $name, $description, $start, $end);
        }

        return new EpgIterator($epg_items, $day_start_ts, $day_start_ts + 86400);
    }

    public function get_archive(MediaURL $media_url)
    {
        return NULL;//$this->session->get_archive();
    }

    public function folder_entered(MediaURL $media_url, &$plugin_cookies)
    {
        if (!isset($media_url->screen_id) ||
            $media_url->screen_id === TvGroupListScreen::ID)
        {
            $this->session->logout();
        }

        $this->session->ensure_logged_in($plugin_cookies);
    }

    // Hook for adding special group items.
    public function add_special_groups(&$items)
    {
		$lang = $this->session->get_lang();
        array_unshift($items,
            array
            (
                PluginRegularFolderItem::media_url =>
                    MediaURL::encode(
                        array
                        (
                            'screen_id' => MoidomVodRootScreen::ID,
                        )),
                PluginRegularFolderItem::caption => $this->session->get_language()->$lang->vod,//'VOD',
                PluginRegularFolderItem::view_item_params => array
                (
                    ViewItemParams::icon_path =>
                        "plugin_file://icons/groups/movies.png"//$this->session->get_icon('mov_root.png')
                )
            ));
    }
}

///////////////////////////////////////////////////////////////////////////
?>
